@@ -57,7 +57,7 @@ def get_data(save_dataset_fd,documents):
 def makeIndividualData(file):
     connect = Grapher(file)
     G, _, _ = connect.graph_formation()
-    df = connect.relative_distance()
+    df = connect.relative_distance(700,850)
     individual_data = from_networkx(G)
 
     feature_cols = ['rd_b', 'rd_r', 'rd_t', 'rd_l', 'line_number', \
